==> open-xchange-guard_2.4.0.orig.tar.bz2: open-xchange-guard-2.4.0/com.openexchange.guard.keys/src/com/openexchange/guard/keys/storage/remoteKeyCache/RemoteKeyCacheSql.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.keys.storage.remoteKeyCache;

public class RemoteKeyCacheSql {

    public static final String SELECT_BY_EMAIL_STMT = "SELECT ring from remote_key_cache rkc INNER JOIN remote_keys rk ON rkc.id = rk.ref WHERE rk.email = ? GROUP BY rkc.id";
    public static final String INSERT_RING_DATA_STMT = "INSERT INTO remote_key_cache (id, ring, created) VALUES (?, ?, NOW()) ON DUPLICATE KEY UPDATE ring = ?";
    public static final String INSERT_RING_ID_STMT = "INSERT INTO remote_keys (id, email, ref) VALUES (?, ?, ?) ON DUPLICATE KEY UPDATE ref = ?";
    public static final String SELECT_OLD_STMT = "SELECT id FROM remote_key_cache WHERE created < DATE_SUB(NOW(), INTERVAL ? DAY);";
    public static final String DELETE_REMOTE_KEYS_STMT = "DELETE FROM remote_keys WHERE ref IN ({@VALUES})";
    public static final String DELETE_REMOTE_KEY_CONTENT_STMT = "DELETE FROM remote_key_cache WHERE id IN ({@VALUES});";
}

==> open-xchange-guard_2.4.2.orig.tar.bz2: open-xchange-guard-2.4.2/com.openexchange.guard.keys/src/com/openexchange/guard/keys/storage/remoteKeyCache/RemoteKeyCacheSql.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.keys.storage.remoteKeyCache;

public class RemoteKeyCacheSql {

    public static final String SELECT_BY_EMAIL_STMT = "SELECT ring from remote_key_cache rkc INNER JOIN remote_keys rk ON rkc.id = rk.ref WHERE rk.email = ? GROUP BY rkc.id";
    public static final String SELECT_BY_ID_STMT = "SELECT ring from remote_key_cache rkc INNER JOIN remote_keys rk ON rkc.id = rk.ref WHERE rk.id = ?";
    public static final String INSERT_RING_DATA_STMT = "INSERT INTO remote_key_cache (id, ring, created) VALUES (?, ?, NOW()) ON DUPLICATE KEY UPDATE ring = ?";
    public static final String INSERT_RING_ID_STMT = "INSERT INTO remote_keys (id, email, ref) VALUES (?, ?, ?) ON DUPLICATE KEY UPDATE ref = ?";
    public static final String SELECT_OLD_STMT = "SELECT id FROM remote_key_cache WHERE created < DATE_SUB(NOW(), INTERVAL ? DAY);";
    public static final String DELETE_REMOTE_KEYS_STMT = "DELETE FROM remote_keys WHERE ref IN ({@VALUES})";
    public static final String DELETE_REMOTE_KEY_CONTENT_STMT = "DELETE FROM remote_key_cache WHERE id IN ({@VALUES});";
}
